@@ -516,6 +516,7 @@ DialogPreferences::DialogPreferences(BaseObjectType* cobject, const Glib::RefPtr
 {
 	// general
 	refGlade->get_widget("check-maximize-window", m_checkMaximizeWindow);
+	refGlade->get_widget("check-ask-to-save-on-exit", m_checkAskToSaveOnExit);
 
 	// encodings
 	refGlade->get_widget_derived("treeview-encodings", m_encodingsTreeView);
@@ -527,11 +528,17 @@ DialogPreferences::DialogPreferences(BaseObjectType* cobject, const Glib::RefPtr
 	refGlade->get_widget("button-add-video-player", m_buttonAddVideoPlayer);
 	refGlade->get_widget("button-remove-video-player", m_buttonRemoveVideoPlayer);
 
+	// others
 
+	// CONNECT SIGNAL
+	
 	// general
 	m_checkMaximizeWindow->signal_toggled().connect(
 			sigc::mem_fun(*this, &DialogPreferences::on_general_maximize_window_changed));
 
+	m_checkAskToSaveOnExit->signal_toggled().connect(
+			sigc::mem_fun(*this, &DialogPreferences::on_general_ask_to_save_on_exit_changed));
+
 	// video preview
 
 	m_buttonAddVideoPlayer->signal_clicked().connect(
@@ -541,14 +548,19 @@ DialogPreferences::DialogPreferences(BaseObjectType* cobject, const Glib::RefPtr
 			sigc::mem_fun(*m_treeViewVideoPlayer, &TreeViewVideoPlayer::on_remove_video_player));
 
 
+	// others
+
 	//
+	
 	Config &cfg = Config::getInstance();
 
 	bool maximize = false;
 	if(cfg.get_value_bool("general", "maximize", maximize))
-	{
 		m_checkMaximizeWindow->set_active(maximize);
-	}
+
+	bool askToSaveOnExit = false;
+	if(cfg.get_value_bool("general", "ask-to-save-on-exit", askToSaveOnExit))
+		m_checkAskToSaveOnExit->set_active(askToSaveOnExit);
 }
 
 
@@ -566,6 +578,16 @@ void DialogPreferences::on_general_maximize_window_changed()
 	save_general();
 }
 
+/*
+ *
+ */
+void DialogPreferences::on_general_ask_to_save_on_exit_changed()
+{
+	bool state = m_checkAskToSaveOnExit->get_active();
+
+	Config::getInstance().set_value_bool("general", "ask-to-save-on-exit", state);
+}
+
 
 
 /*
