@@ -612,6 +612,9 @@ gint64 GstLaunch::get_percent()
  */
 bool GstLaunch::seek(gint64 pos)
 {
+	if(pos < 0)
+		pos = 0;
+
 	se_debug_message(SE_DEBUG_GSTREAMER, "%d", pos);
 
 	CLAMP(pos, 0, get_duration());
@@ -646,6 +649,9 @@ bool GstLaunch::seek(gint64 pos)
  */
 bool GstLaunch::seek(gint64 start, gint64 end)
 {
+	if(start < 0) start = 0;
+	if(end < 0) end = 0;
+
 	se_debug_message(SE_DEBUG_GSTREAMER, "%d %d", start, end);
 
 	if(start > end)
@@ -685,7 +691,7 @@ bool GstLaunch::seek(gint64 start, gint64 end)
  *	fonction callback pour Glib::timeout()
  */
 bool GstLaunch::on_timeout()
-{
+{	
 	se_debug(SE_DEBUG_GSTREAMER);
 
 	m_signal_timeout();//get_position());
