@@ -158,7 +158,8 @@ MenuBar::MenuBar(Gtk::Window &window)
 		Gtk::AccelKey('c', Gdk::MOD1_MASK), SIGNAL(on_spell_check)); 
 	
 	m_refActionGroup->add(Gtk::Action::create("set-all-end-time", _("Set All End Time")), SIGNAL(on_set_all_end_time));
-	m_refActionGroup->add(Gtk::Action::create("style-editor", _("Style Editor")), SIGNAL(on_style_editor));
+	m_refActionGroup->add(Gtk::Action::create("style-editor", _("Style Editor")), 
+			Gtk::AccelKey('a', Gdk::MOD1_MASK), SIGNAL(on_style_editor));
 
 	m_refActionGroup->add(Gtk::Action::create("apply-translation", Gtk::Stock::APPLY, _("Apply Translation")), SIGNAL(on_apply_translation));
 
