@@ -369,8 +369,8 @@ bool SubtitleASS::save(const Glib::ustring &filename, const Glib::ustring &encod
 
 			oss << "Dialogue: "
 				<< subtitle.get_layer() << "," 
-				<< subtitletime_to_ass_time(subtitle.get_start().str()) << ","
-				<< subtitletime_to_ass_time(subtitle.get_end().str()) << ","
+				<< subtitletime_to_ass_time(subtitle.get_start()) << ","
+				<< subtitletime_to_ass_time(subtitle.get_end()) << ","
 				<< utf8_to_charset(subtitle.get_style()) << ","
 				<< utf8_to_charset(subtitle.get_name()) << ","
 				<< std::setw(4) << std::setfill('0') << subtitle.get_margin_l() << ","
@@ -544,8 +544,9 @@ bool SubtitleASS::readEvents(std::ifstream &file)
 			subtitle.set_num(num);
 			// marked/layer
 			subtitle.set_layer(array[0]);
-			subtitle.set_start(ass_time_to_subtitletime(array[1]));
-			subtitle.set_end(ass_time_to_subtitletime(array[2]));
+			subtitle.set_start_and_end(
+					ass_time_to_subtitletime(array[1]) ,
+					ass_time_to_subtitletime(array[2]) );
 
 
 			subtitle.set_style(clean_style_name( charset_to_utf8(array[3]) ));
@@ -602,13 +603,18 @@ std::vector< std::string > SubtitleASS::build(const std::string &line, unsigned
  *	convertir le temps utiliser par subtitle editor en temps valide pour le format SSA
  *	0:00:00.000 -> 0:00:00.00
  */
-Glib::ustring SubtitleASS::subtitletime_to_ass_time(const Glib::ustring &time)
+Glib::ustring SubtitleASS::subtitletime_to_ass_time(const SubtitleTime &time)
 {
-#warning "TODO: fixme SubtitleTime to ASS time"
+	int msecs = (int)(time.msecs * 0.1);
 
-	//SubtitleTime t(time);
+	gchar *tmp = g_strdup_printf("%01i:%02i:%02i.%02i",
+			time.hours, time.mins, time.secs, msecs);
 
-	return time;
+	Glib::ustring res(tmp);
+
+	g_free(tmp);
+
+	return res;
 }
 
 /*
