@@ -95,7 +95,7 @@ protected:
 	 *	convertir le temps utiliser par subtitle editor en temps valide pour le format ASS
 	 *	0:00:00.000 -> 0:00:00.00
 	 */
-	Glib::ustring subtitletime_to_ass_time(const Glib::ustring &time);
+	Glib::ustring subtitletime_to_ass_time(const SubtitleTime &time);
 
 	/*
 	 *	convertir un temps ASS en SubtitleTime (string)
