@@ -142,8 +142,9 @@ bool SubtitleMPsub::open(const Glib::ustring &filename, const Glib::ustring &enc
 			//
 			SubtitleModifier subtitle(m_subtitleModel->append());
 
-			subtitle.set_start(t_start);
-			subtitle.set_end(t_end);
+			subtitle.set_start_and_end(
+					t_start, 
+					t_end);
 			subtitle.set_text(text);
 
 
