@@ -98,11 +98,11 @@ bool SubtitleMicroDVD::open(const Glib::ustring &filename, const Glib::ustring &
 		throw SubtitleException("SubtitleMicroDVD", _("I can't open this file."));
 	}
 
-	unsigned int start=0, end=0;
+	int start=0, end=0;
 
 #warning "fixme > FPS convert"
 
-	double fps = 23.976;
+	double framerate = 23.976;
 	
 	std::string line;
 	while(!file.eof() && std::getline(file, line))
@@ -116,8 +116,9 @@ bool SubtitleMicroDVD::open(const Glib::ustring &filename, const Glib::ustring &
 
 			SubtitleModifier subtitle(m_subtitleModel->append());
 
-			subtitle.set_start( SubtitleTime((long int)(start*fps)));
-			subtitle.set_end( SubtitleTime((long int)(end*fps)));
+			subtitle.set_start_and_end( 
+					SubtitleTime::frame_to_time(start, framerate),
+					SubtitleTime::frame_to_time(end, framerate));
 
 			Glib::ustring txt = check_end_char(charset_to_utf8(text));
 
@@ -148,9 +149,11 @@ bool SubtitleMicroDVD::save(const Glib::ustring &filename, const Glib::ustring &
 	}
 
 	// TODO : change!
-#warning "fixme > FPS convert"
-	double fps = 23.976;
-	
+#warning "fixme > framerate use Config"
+	double framerate = 23.976;
+
+	//file << "{0}{0}23.976" << std::endl;
+
 	Glib::ustring text;
 	
 	Gtk::TreeNodeChildren rows = m_subtitleModel->children();
@@ -166,9 +169,9 @@ bool SubtitleMicroDVD::save(const Glib::ustring &filename, const Glib::ustring &
 		newline_to_characters(text, "|");
 
 		file << "{"
-			<< (unsigned int)(start.totalmsecs / fps)
+			<< SubtitleTime::time_to_frame(start, framerate)
 			<< "}{"
-			<< (unsigned int)(end.totalmsecs / fps)
+			<< SubtitleTime::time_to_frame(end, framerate)
 			<< "}"
 			<< utf8_to_charset(text)
 			<< std::endl;
