@@ -379,8 +379,8 @@ bool SubtitleSSA::save(const Glib::ustring &filename, const Glib::ustring &encod
 			oss << "Dialogue: "
 				<< "Marked=" << 0/*(*it)[column.flag]*/ << "," 
 				
-				<< subtitletime_to_ssa_time(subtitle.get_start().str()) << "," 
-				<< subtitletime_to_ssa_time(subtitle.get_end().str()) << ","
+				<< subtitletime_to_ssa_time(subtitle.get_start()) << "," 
+				<< subtitletime_to_ssa_time(subtitle.get_end()) << ","
 				
 				<< utf8_to_charset(subtitle.get_style()) << ","
 				<< utf8_to_charset(subtitle.get_name()) << ","
@@ -555,8 +555,9 @@ bool SubtitleSSA::readEvents(std::ifstream &file)
 			
 			subtitle.set_num( num );
 			// marked/layer
-			subtitle.set_start( ass_time_to_subtitletime(array[1]));
-			subtitle.set_end( ass_time_to_subtitletime(array[2]));
+			subtitle.set_start_and_end(
+					ass_time_to_subtitletime(array[1]),
+					ass_time_to_subtitletime(array[2]));
 
 
 			subtitle.set_style( charset_to_utf8(clean_style_name( array[3] )));
@@ -613,13 +614,18 @@ std::vector< std::string > SubtitleSSA::build(const std::string &line, unsigned
  *	en temps valide pour le format SSA
  *	0:00:00.000 -> 0:00:00.00
  */
-Glib::ustring SubtitleSSA::subtitletime_to_ssa_time(const Glib::ustring &time)
+Glib::ustring SubtitleSSA::subtitletime_to_ssa_time(const SubtitleTime &time)
 {
-	//Glib::ustring str = time;
-	//Glib::ustring::size_type f = str.find(',');
-	//str.replace(f, 1, ".");
-	//return str;
-	return time;
+	int msecs = (int)(time.msecs * 0.1);
+
+	gchar *tmp = g_strdup_printf("%01i:%02i:%02i.%02i",
+			time.hours, time.mins, time.secs, msecs);
+
+	Glib::ustring res(tmp);
+
+	g_free(tmp);
+
+	return res;
 }
 
 /*
