@@ -105,7 +105,7 @@ protected:
 	 *	en temps valide pour le format SSA
 	 *	0:00:00.000 -> 0:00:00.00
 	 */
-	Glib::ustring subtitletime_to_ssa_time(const Glib::ustring &time);
+	Glib::ustring subtitletime_to_ssa_time(const SubtitleTime &time);
 
 	/*
 	 *	convertir le temps SSA en SubtitleTime (string)
