@@ -110,32 +110,19 @@ bool SubtitleSubViewer2::open(const Glib::ustring &filename, const Glib::ustring
 						&start[0], &start[1], &start[2], &start[3], 
 						&end[0], &end[1], &end[2], &end[3]) == 8)
 			{
-				Glib::ustring text;
-				int count = 0; // permet de compter le nombre de ligne
-
-				while(std::getline(file, line))
+				if(std::getline(file, line))
 				{
-					line = check_end_char(charset_to_utf8(line));
+					Glib::ustring text = check_end_char(charset_to_utf8(line));
 
-					if(line.size()==0)
-						break;
-					else
-					{
-						if(count > 0) // s'il y a deja une ligne alors on utlise le | pour le retour a la ligne
-							text += get_newline();
+					SubtitleModifier subtitle(m_subtitleModel->append());
 
-						text += line;
-						++count;
-					}
+					characters_to_newline(text, "[br]");
+
+					subtitle.set_text(text);
+					subtitle.set_start_and_end(
+							SubtitleTime(start[0], start[1], start[2], start[3]),
+							SubtitleTime(end[0], end[1], end[2], end[3]));
 				}
-		
-				SubtitleModifier subtitle(m_subtitleModel->append());
-
-				characters_to_newline(text, "[br]");
-
-				subtitle.set_text(text);
-				subtitle.set_start(SubtitleTime(start[0], start[1], start[2], start[3]));
-				subtitle.set_end(SubtitleTime(end[0], end[1], end[2], end[3]));
 			}
 		}
 	}
