@@ -176,6 +176,7 @@ public:
 		m_textViewCell = manage(new TextViewCell(path));
 		m_textViewCell->set_wrap_mode(Gtk::WRAP_NONE);
 		m_textViewCell->set_text(property_text());
+		m_textViewCell->set_size_request(cell_area.get_width(), cell_area.get_height());
 
 		m_textViewCell->signal_edited().connect(
 				sigc::mem_fun(*this, &CellRendererTextMultiline::edited));
@@ -201,8 +202,10 @@ SubtitleView::SubtitleView(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Gl
 	se_debug(SE_DEBUG_VIEW);
 
 	m_refDocument = SE::getInstance()->getDocument();
-		
-	set_model(m_refDocument->m_subtitleModel);
+	// cela est connecter au dernier moment dans SubtitleEditor::show()
+	// c'est plus rapide ainsi ...
+	//
+	//set_model(m_refDocument->m_subtitleModel);
 
 	m_subtitleModel = m_refDocument->m_subtitleModel;
 	m_styleModel = m_refDocument->m_styleModel;
@@ -313,7 +316,7 @@ void SubtitleView::saveCfg()
 void SubtitleView::set_tooltips(Gtk::TreeViewColumn *column, const Glib::ustring &text)
 {
 	se_debug_message(SE_DEBUG_VIEW, "[%s]=%s", column->get_title().c_str(), text.c_str());
-
+/*
 	Gtk::EventBox *event = manage(new Gtk::EventBox);
 
 	Gtk::Label* label = manage(new Gtk::Label(column->get_title()));
@@ -325,6 +328,7 @@ void SubtitleView::set_tooltips(Gtk::TreeViewColumn *column, const Glib::ustring
 
 	column->set_widget(*event);
 	event->show_all();
+*/
 }
 
 /*
