@@ -335,6 +335,9 @@ TimeDrawingArea::TimeDrawingArea(BaseObjectType* cobject, const Glib::RefPtr<Gno
 {
 }
 
+/*
+ *
+ */
 void TimeDrawingArea::on_realize()
 {
 	DrawingArea::on_realize();
@@ -469,6 +472,9 @@ void TimeDrawingArea::draw_time(gint64 sec)
 	}
 }
 
+/*
+ *
+ */
 void TimeDrawingArea::redraw()
 {
 }
@@ -543,11 +549,17 @@ void WaveformDrawingArea::redraw()
 	}
 }
 
+/*
+ *
+ */
 void WaveformDrawingArea::on_realize()
 {
 	DrawingArea::on_realize();
 }
 
+/*
+ *
+ */
 bool WaveformDrawingArea::on_expose_event(GdkEventExpose *ev)
 {
 	// avec glade il n'y a pas d'appel a on_realize...
@@ -577,7 +589,9 @@ bool WaveformDrawingArea::on_expose_event(GdkEventExpose *ev)
 	return state;
 }
 
-
+/*
+ *
+ */
 void WaveformDrawingArea::draw_channel(unsigned int channel, float max, int y, int height)
 {
 	guint64 startx = get_start_area();
@@ -609,6 +623,9 @@ void WaveformDrawingArea::draw_channel(unsigned int channel, float max, int y, i
 #undef draw
 }
 
+/*
+ *
+ */
 void WaveformDrawingArea::draw_marker(const Gdk::Color &color, gint64 start, gint64 end)
 {
 	int width = get_width();
@@ -634,7 +651,9 @@ void WaveformDrawingArea::draw_marker(const Gdk::Color &color, gint64 start, gin
 	}
 }
 
-
+/*
+ *
+ */
 void WaveformDrawingArea::draw_markers()
 {
 	Document *doc = SE::getInstance()->getDocument();
@@ -687,11 +706,17 @@ void WaveformDrawingArea::draw_markers()
 
 }
 
+/*
+ *
+ */
 void WaveformDrawingArea::set_current_play(gint64 pos)
 {
 	m_current_play = pos;
 }
 
+/*
+ *
+ */
 void WaveformDrawingArea::draw_play_position()
 {
 	int startx = get_start_area();
@@ -711,7 +736,9 @@ void WaveformDrawingArea::on_subtitle_view_selection_changed(Gtk::TreeIter it)
 	queue_draw();
 }
 
-
+/*
+ *
+ */
 bool WaveformDrawingArea::on_button_press_event(GdkEventButton *ev)
 {
 	bool state = DrawingArea::on_button_press_event(ev);
@@ -751,6 +778,9 @@ bool WaveformDrawingArea::on_button_press_event(GdkEventButton *ev)
 	return state;
 }
 
+/*
+ *
+ */
 bool WaveformDrawingArea::on_button_release_event(GdkEventButton *ev)
 {
 	bool state = DrawingArea::on_button_release_event(ev);
@@ -758,7 +788,9 @@ bool WaveformDrawingArea::on_button_release_event(GdkEventButton *ev)
 	return state;
 }
 
-
+/*
+ *
+ */
 bool WaveformDrawingArea::on_motion_notify_event(GdkEventMotion *ev)
 {
 	bool state = DrawingArea::on_motion_notify_event(ev);
@@ -818,7 +850,13 @@ TimingSystem::TimingSystem(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Gl
 	refGlade->get_widget("button-play-next-subtitle", m_buttonNextSubtitle);
 	refGlade->get_widget("button-stop", m_buttonStop);
 
+	refGlade->get_widget("button-play-previous-second", m_buttonPlayPreviousSecond);
+	refGlade->get_widget("button-play-first-second", m_buttonPlayFirstSecond);
+	refGlade->get_widget("button-play-last-second", m_buttonPlayLastSecond);
+	refGlade->get_widget("button-play-next-second", m_buttonPlayNextSecond);
+
 	// connect l'interface
+	// Play Subtitle
 	m_buttonPlay->signal_clicked().connect(
 			sigc::mem_fun((SubtitleEditor*)SE::getInstance(), &SubtitleEditor::on_timing_play_current_subtitle));
 	
@@ -831,6 +869,20 @@ TimingSystem::TimingSystem(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Gl
 	m_buttonNextSubtitle->signal_clicked().connect(
 			sigc::mem_fun((SubtitleEditor*)SE::getInstance(), &SubtitleEditor::on_timing_play_next_subtitle));
 
+	// Play Second
+	m_buttonPlayPreviousSecond->signal_clicked().connect(
+			sigc::mem_fun((SubtitleEditor*)SE::getInstance(), &SubtitleEditor::on_timing_play_previous_second));
+	
+	m_buttonPlayFirstSecond->signal_clicked().connect(
+			sigc::mem_fun((SubtitleEditor*)SE::getInstance(), &SubtitleEditor::on_timing_play_first_second));
+	
+	m_buttonPlayLastSecond->signal_clicked().connect(
+			sigc::mem_fun((SubtitleEditor*)SE::getInstance(), &SubtitleEditor::on_timing_play_last_second));
+	
+	m_buttonPlayNextSecond->signal_clicked().connect(
+			sigc::mem_fun((SubtitleEditor*)SE::getInstance(), &SubtitleEditor::on_timing_play_next_second));
+
+	// Waveform
 	m_spinZoom->signal_value_changed().connect(
 			sigc::mem_fun(*this, &TimingSystem::on_spin_zoom_changed));
 	
@@ -940,8 +992,6 @@ void TimingSystem::on_size_allocate(Gtk::Allocation &al)
 	}
 }
 
-
-
 /*
  *
  */
@@ -1574,7 +1624,7 @@ bool WaveformDrawingAreaCairo::on_button_press_event(GdkEventButton *ev)
 {
 	bool state = DrawingArea::on_button_press_event(ev);
 
-	Gtk::TreeIter it = SE::getInstance()->getSubtitleView()->getSelected();
+	SubtitleModifier subtitle(SE::getInstance()->getSubtitleView()->getSelected());
 
 	SubtitleColumnRecorder m_column;
 	// il faut prendre en compte la hscrollbar
@@ -1582,11 +1632,11 @@ bool WaveformDrawingAreaCairo::on_button_press_event(GdkEventButton *ev)
 
 	gint64 time = get_time_by_pos(x);
 	
-	Glib::ustring time_str = getTime2MSecs(time / GST_MSECOND).str();
+	SubtitleTime new_time( time / GST_MSECOND);
 
-	if(ev->button == 1 && it)
+	if(ev->button == 1 && subtitle)
 	{
-		(*it)[m_column.start] = time_str;
+		subtitle.set_start(new_time);
 
 		queue_draw();
 	}
@@ -1601,9 +1651,9 @@ bool WaveformDrawingAreaCairo::on_button_press_event(GdkEventButton *ev)
 			m_media->play();
 		}
 	}
-	else if(ev->button == 3 && it)
+	else if(ev->button == 3 && subtitle)
 	{
-		(*it)[m_column.end] = time_str;
+		subtitle.set_end(new_time);
 
 		queue_draw();
 	}
@@ -1619,8 +1669,9 @@ bool WaveformDrawingAreaCairo::on_motion_notify_event(GdkEventMotion *ev)
 {
 	bool state = DrawingArea::on_motion_notify_event(ev);
 
-	Gtk::TreeIter it = SE::getInstance()->getSubtitleView()->getSelected();
-	if(!it)
+	SubtitleModifier subtitle(SE::getInstance()->getSubtitleView()->getSelected());
+
+	if(!subtitle)
 		return state;
 
 	SubtitleColumnRecorder m_column;
@@ -1631,17 +1682,17 @@ bool WaveformDrawingAreaCairo::on_motion_notify_event(GdkEventMotion *ev)
 
 	gint64 time = get_time_by_pos(x);
 
-	Glib::ustring time_str = getTime2MSecs(time / GST_MSECOND).str();
+	SubtitleTime new_time( time / GST_MSECOND );
 
 	if(ev->state & Gdk::BUTTON1_MASK)
 	{
-		(*it)[m_column.end] = time_str;
+		subtitle.set_end(new_time);
 
 		queue_draw();
 	}
 	else if(ev->state & Gdk::BUTTON3_MASK)
 	{
-		(*it)[m_column.end] = time_str;
+		subtitle.set_end(new_time);
 
 		queue_draw();
 	}
