@@ -69,9 +69,7 @@ public:
 	SubtitleOption();
 
 public:
-	Glib::ustring	m_subtitlefile;
-	Glib::ustring m_moviefile;
-	bool m_maximize;
+	bool check_gstreamer;
 };
 
 /*
@@ -80,24 +78,12 @@ public:
 SubtitleOption::SubtitleOption()
 :Glib::OptionGroup("subtitleeditor", "description ....", "help...")
 {
-	m_maximize = false;
+	check_gstreamer = false;
 
-	Glib::OptionEntry entry1;
-	entry1.set_long_name("maximize");
-	entry1.set_description("Maximize window");
-	add_entry(entry1, m_maximize);
-
-	Glib::OptionEntry entry2;
-	entry2.set_long_name("sub");
-	entry2.set_short_name('s');
-	entry2.set_description("The subtitle file");
-	add_entry(entry2, m_subtitlefile);
-
-	Glib::OptionEntry entry3;
-	entry3.set_long_name("movie");
-	entry3.set_short_name('m');
-	entry3.set_description("The movie file");
-	add_entry(entry3, m_moviefile);
+	Glib::OptionEntry entry4;
+	entry4.set_long_name("check-gstreamer");
+	entry4.set_description("Check Gstreamer to the presence of certain element used by subtitleeditor");
+	add_entry(entry4, check_gstreamer);
 }
 
 /*
@@ -109,9 +95,7 @@ void check_default_config()
 
 	Config &cfg = Config::getInstance();
 
-	/*
-	 * piti check... ~/.subtitleeditor
-	 */
+	// piti check... ~/.subtitleeditor
 	Glib::ustring path_se = Glib::build_filename(Glib::get_home_dir(), ".subtitleeditor");
 	if(Glib::file_test(path_se, Glib::FILE_TEST_IS_DIR) == false)
 	{
@@ -119,16 +103,12 @@ void check_default_config()
 		system(cmd.c_str());
 	}
 
-	/*
-	 *	GENERAL
-	 */
+	// GENERAL
 	if(!cfg.has_key("general", "maximize"))
 		cfg.set_value_bool("general", "maximize", false);
 
 
-	/*
-	 *	ENCODINGS
-	 */
+	// ENCODINGS
 	if(!cfg.has_key("encodings", "default"))
 		cfg.set_value_string("encodings", "encodings", "ISO-8859-15;UTF-8;");
 
@@ -144,10 +124,7 @@ void check_default_config()
 	if(!cfg.has_key("encodings", "used-auto-detected"))
 		cfg.set_value_bool("encodings", "used-auto-detected", true);
 
-	/*
-	 *	VIDEO-PLAYER
-	 */
-	
+	// VIDEO-PLAYER	
 	if(!cfg.has_key("video-player", "default"))
 	{
 		//cfg.set_comment("video-player", "video-player", "blablabla");
@@ -163,37 +140,8 @@ void check_default_config()
 		//cfg.set_value_string("video-player", "gstreamer", 
 		//		"gst-launch playbin uri=\"#video_uri\" subfile=\"#subtitle_uri\" subtitle-font-desc=\"Comic Sans MS Bold 20\"");
 	}
-	else
-	{
-		// TODO enlever.
-		// un patch pour le passage 0.8.1 -> 0.9
-		std::list<Glib::ustring> keys;
-		if(cfg.get_keys("video-player", keys))
-		{
-			Glib::ustring cmd;
-			
-			std::list<Glib::ustring>::const_iterator it;
-			for(it = keys.begin(); it != keys.end(); ++it)
-			{
-				if((*it) == "default")
-					continue;
-				
-				if(cfg.get_value_string("video-player", *it, cmd))
-				{
-					if(cmd.find("#msecs") != Glib::ustring::npos)
-					{
-						find_and_replace(cmd, "#msecs", "#seconds");
-						cfg.set_value_string("video-player", *it, cmd);
-					}
-				}
-			}
-		}
-	}
-
-	/*
-	 *	TIMING-SYSTEM
-	 */
 
+	// TIMING-SYSTEM
 	if(!cfg.has_key("timing-system", "audio-sink"))
 		cfg.set_value_string("timing-system", "audio-sink", "autoaudiosink");
 	
@@ -201,74 +149,125 @@ void check_default_config()
 		cfg.set_value_string("timing-system", "video-sink", "ximagesink");
 }
 
+/*
+ *	teste GStreamer
+ */
+void check_gstreamer()
+{
+	guint major, minor, micro, nano;
+
+	gst_version(&major, &minor, &micro, &nano);
+
+	g_print("gstreamer info : %d.%d.%d\n", major, minor, micro);
+
+#define check_element(name) \
+	{ \
+		GstElement *el = gst_element_factory_make(name, name); \
+		if(!el) \
+			std::cerr << "create \"" << name << "\" FAILED!" << std::endl; \
+		else { \
+			std::cerr << "create \"" << name << "\" OK!" << std::endl; \
+			gst_object_unref(GST_OBJECT(el)); } \
+	}
+
+	check_element("filesrc");
+	check_element("decodebin");
+	check_element("audioconvert");
+	check_element("level");
+	check_element("fakesink");
+	check_element("ximagesink");
+
+#undef check_element
+}
 
 /*
  *
  */
 int main(int argc, char *argv[])
 {
+	// Init Debug
 	se_debug_init(argc, argv);
 	se_debug_message(SE_DEBUG_APP, "Startup subtitle version %s", VERSION);
 	
+	// Bindtextdomain
 	bindtextdomain(PACKAGE, PACKAGE_LOCALE_DIR);
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 	textdomain(PACKAGE);
 
+	// Init Gtk+
 	se_debug_message(SE_DEBUG_APP, "Init Gtk+");
 
-	Gtk::Main kit(argc, argv);
+	Gtk::Main kit(argc, argv/*, context*/);
 
 	g_set_application_name("subtitleeditor");
 
+	// Options
+	se_debug_message(SE_DEBUG_APP, "Options");
+
+	SubtitleOption options;
+	Glib::OptionContext context("[FILE...]");
+
+	context.set_main_group(options);
+	
+	try
+	{
+		context.parse(argc, argv);
+	}
+	catch(const Glib::Error &ex)
+	{
+		std::cerr << "Error loading options : " << ex.what() << std::endl;
+		//return EXIT_FAILURE;
+	}
+
+	// Init GStreamer 
 	se_debug_message(SE_DEBUG_APP, "Init GStreamer");
 	
 	gst_init(&argc,&argv);
 
+	// check gstreamer ?
+	if(options.check_gstreamer)
+	{
+		check_gstreamer();
+		return EXIT_SUCCESS;
+	}
+
+	// check default config
 	se_debug_message(SE_DEBUG_APP, "Check default config");
 	
 	check_default_config();
 
+	// Create subtitleeditor instance
 	se_debug_message(SE_DEBUG_APP, "Create SubtitleEditor instance");
 
 	SubtitleEditor* editor = SubtitleEditor::getInstance();	
 
-	
-	se_debug_message(SE_DEBUG_APP, "Load arg option");
-
-	try
+	if(!editor)
 	{
-		SubtitleOption options;
-		Glib::OptionContext context;
-
-		context.set_main_group(options);
-		context.parse(argc, argv);
-
-		if(!options.m_subtitlefile.empty())
-			editor->open_subtitle(options.m_subtitlefile);
-
-		if(!options.m_moviefile.empty())
-			editor->open_movie(options.m_moviefile);
-
-		if(options.m_maximize)
-			editor->maximize();
-	}
-	catch(const Glib::Error &ex)
-	{
-#warning "FIXME pas de crash!!"
-		se_debug_message(SE_DEBUG_APP, "Load arg option failed (%s)", ex.what().c_str());
-		//delete editor;
-		//return 1;
+		std::cerr << "Can't create subtitleeditor instance!" << std::endl;
+		return EXIT_FAILURE;
 	}
 
+	// Open subtitle file ?	
+	if(argc > 1)
+	{
+		if(	Glib::file_test(argv[1], Glib::FILE_TEST_EXISTS | Glib::FILE_TEST_IS_REGULAR) && 
+				Glib::file_test(argv[1], Glib::FILE_TEST_IS_DIR) == false)
+		{
+			editor->open_subtitle(argv[1]);
+		}
+	}
 
+	// launch and show
 	se_debug_message(SE_DEBUG_APP, "Run SubtitleEditor");
 
+	editor->show();
+	
 	kit.run(*editor);
 
 	se_debug_message(SE_DEBUG_APP, "Delete SubtitleEditor");
 	
 	delete editor;
 
-	return 0;
+	return EXIT_SUCCESS;
 }
 
